@@ -407,7 +407,11 @@ class QuestionRubric:
         self.question = question
         self.rubric_items: RubricItem = []
         # TODO: This does not support grouped rubrics
-        raw_rubric_items = question.get_rubric()
+        self.reset_rubric()
+
+    def reset_rubric(self):
+        self.rubric_items = []
+        raw_rubric_items = self.question.get_rubric()
         if raw_rubric_items:
             for item in raw_rubric_items.get("rubric_items", []):
                 self.rubric_items.append(RubricItem(**item))
@@ -446,7 +450,7 @@ class QuestionRubric:
             return True
         return False
 
-    def grade(self, submission_id: int, selection_list, save_group: bool=False) -> bool:
+    def grade(self, submission_id: int, selection_list, save_group: bool=False, qid: str="", depth: int=0, max_depth: int=5) -> bool:
         """
         Takes in the submission id to grade, a selection list which is a list of just true and false
         in the same order as the internal rubric or a dictionary mapping rubric item to bool (if it is selected.)
@@ -473,7 +477,17 @@ class QuestionRubric:
         else:
             raise ValueError(f"{type(selection_list)} not supported")
 
-        return self.question.grade(submission_id, data, save_group=save_group)
+        res = self.question.grade(submission_id, data, save_group=save_group)
+        if res.status_code == 410 and json.loads(res.content)["error"] == "changed" and depth < max_depth:
+            print(f"{qid}Rubric items were changed ({res}, {res.content})! Attempting to update them and retry...")
+            self.reset_rubric()
+            return self.grade(submission_id, selection_list, save_group=save_group, qid=qid, depth=depth + 1, max_depth=max_depth)
+        else:
+            if depth >= max_depth:
+                print(f"{qid}Reached max depth when attempting to change rubric items!")
+            elif depth > 0 and res:
+                print(f"{qid} Fixed rubric grading issue!")
+            return res
 
     def __len__(self):
         return len(self.rubric_items)
