@@ -1,7 +1,7 @@
 import click
 
 from fullGSapi.cli.build import build
-from fullGSapi.cli.login import login
+from fullGSapi.cli.login import login, check_login
 from fullGSapi.cli.download_commands import download_grades
 from fullGSapi.cli.submit import submit
 from fullGSapi.cli.utils import login_token_path_option
@@ -22,6 +22,7 @@ def cli(ctx: click.Context, debug: bool, tokenpath: str):
 
 cli.add_command(build)
 cli.add_command(login)
+cli.add_command(check_login)
 cli.add_command(download_grades)
 cli.add_command(submit)
 
